@@ -151,11 +151,10 @@ C<routine> method.
 
 =cut
 
-#' fool emacs
-
 package PDL::Func;
 
 use strict;
+use warnings;
 use Carp;
 
 ####################################################################
@@ -323,7 +322,7 @@ sub _check_attr {
     return unless $self->{flags}{changed};
 
     my @emsg;
-    foreach my $name ( keys %{ $self->{attributes} } ) {
+    foreach my $name ( sort keys %{ $self->{attributes} } ) {
 	if( $self->{attributes}{$name}{required} ) {
 	    push @emsg, $name unless defined($self->{values}{$name});
 	}
